/*
 * Copyright (c) 2011 by the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.powertac.auctioneer;

import java.util.List;

import org.apache.log4j.Logger;
import org.powertac.common.Competition;
import org.powertac.common.PluginConfig;
import org.powertac.common.interfaces.InitializationService;
import org.powertac.common.interfaces.ServerProperties;
import org.powertac.common.repo.PluginConfigRepo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class AuctionInitializationService implements InitializationService
{
  static private Logger log = Logger.getLogger(AuctionInitializationService.class);

  @Autowired
  private PluginConfigRepo pluginConfigRepo;

  @Autowired
  private AuctionService auctionService;
  
  @Autowired
  private ServerProperties serverProps;

  public void setDefaults ()
  {
    double sellerSurplus =
        serverProps.getDoubleProperty("auctioneer.sellerSurplus", 0.5);
    double defaultMargin =
        serverProps.getDoubleProperty("auctioneer.defaultMargin", 0.2);
    pluginConfigRepo.makePluginConfig("Auctioneer", "init")
      .addConfiguration("sellerSurplus", Double.toString(sellerSurplus))
      .addConfiguration("defaultMargin", Double.toString(defaultMargin));
  }

  public String initialize (Competition competition, List<String> completedInits)
  {
    PluginConfig auctioneer = pluginConfigRepo.findByRoleName("Auctioneer");
    if (auctioneer == null) {
      log.error("PluginConfig for Auctioneer does not exist.");
    }
    else {
      auctionService.init(auctioneer);
      return "Auctioneer";
    }
    return "fail";
  }
}
